// src/shared.ts
import { ref } from "vue";
import { createHighlighter } from "shiki";
function useHighlighter() {
  const highlightedCode = ref("");
  async function highlightCode(codeContent, themes) {
    const highlighter = await createHighlighter({
      langs: [],
      themes: Object.values(themes)
    });
    await highlighter.loadLanguage("templ");
    highlightedCode.value = highlighter.codeToHtml(codeContent, {
      lang: "templ",
      themes,
      defaultColor: false
    });
  }
  return {
    highlightedCode,
    highlightCode
  };
}
function executeScriptsTick() {
  const previewContent = document.querySelector(
    ".preview-content"
  );
  if (previewContent) {
    const observer = new MutationObserver((mutations) => {
      mutations.forEach((mutation) => {
        if (mutation.type === "childList") {
          executeScripts(mutation.target);
        }
      });
    });
    observer.observe(previewContent, { childList: true });
    executeScripts(previewContent);
  }
}
function executeScripts(container) {
  const scripts = container.querySelectorAll("script");
  scripts.forEach((script) => {
    const newScript = document.createElement("script");
    newScript.textContent = script.textContent;
    document.body.appendChild(newScript).parentNode?.removeChild(newScript);
  });
}
export {
  executeScriptsTick,
  useHighlighter
};
