import { CodeExtractorOptions } from './types';
/**
 * Class to extract templated blocks of code.
 */
export declare class CodeExtractor {
    private code;
    private options;
    private static readonly defaultOptions;
    private static readonly packageRegex;
    private static readonly importRegex;
    private static readonly constRegex;
    private static readonly varRegex;
    private static readonly typeRegex;
    private static readonly exportedTemplRegex;
    private static readonly allTemplRegex;
    /**
     * Constructs a CodeExtractor instance.
     *
     * @param {string} code - The code string to scan for templated blocks.
     * @param {CodeExtractorOptions} [options] - Configuration options to include or exclude certain keywords.
     */
    constructor(code: string, options?: CodeExtractorOptions);
    /**
     * Extracts templated blocks of code based on the provided options.
     *
     * @returns {string[]} An array containing a single string with the full templated block including specified inclusions.
     */
    extract(): string[];
    private getPackageMatch;
    private getImportStatements;
    private getConstStatements;
    private getVarStatements;
    private getTypeStatements;
    private extractTemplBlock;
    private getAllMatches;
}
